@@ -3,7 +3,6 @@ package AWS::S3::Request::GetPreSignedUrl;
 use Moose;
 
 use AWS::S3::Signer;
-use URI::Escape qw(uri_escape);
 
 with 'AWS::S3::Roles::Request';
 
@@ -31,7 +30,7 @@ sub request {
     my $signed_uri = $uri->as_string
         . '?AWSAccessKeyId=' . $s->s3->access_key_id
         . '&Expires=' . $s->expires
-        . '&Signature=' . uri_escape( $signer->signature );
+        . '&Signature=' . $signer->signature;
 
     return $signed_uri;
 }
